@@ -2,10 +2,10 @@
  * @package     hubzero-vncproxy
  * @file		vncproxy.c
  * @author      Nicholas J. Kisseberth <nkissebe@purdue.edu>
- * @copyright   Copyright (c) 2010-2011 Purdue University. All rights reserved.
+ * @copyright   Copyright (c) 2010-2012 Purdue University. All rights reserved.
  * @license     http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
  *
- * Copyright (c) 2010-2011 Purdue University
+ * Copyright (c) 2010-2012 Purdue University
  * All rights reserved.
  *
  * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
@@ -267,8 +267,8 @@ main(int argc, const char * const argv[])
 			break;
 
 		switch (c) {
-			case 'r': fprintf(stdout, "vncproxy (helper) 1.2\n");
-					  fprintf(stdout, "Copyright (c) 2010-2011 Purdue University\n");
+			case 'r': fprintf(stdout, "vncproxy 2.1\n");
+					  fprintf(stdout, "Copyright (c) 2010-2012 Purdue University\n");
 					  fprintf(stdout, "This is free software: you can redistribute it and/or modify it under the terms\n");
 					  fprintf(stdout, "of the GNU Lesser General Public License version 3 or later.\n");
 					  fprintf(stdout, "<http://gnu.org/licenses/gpl.html>\n"); 
